@@ -64,6 +64,6 @@ class DistributedMixin(BASE):
         except:  # noqa
             return 1
 
-    def add(self, *args, **kwargs) -> RETURN_TYPE:
+    def add(self, *args, **kwargs):
+        super(DistributedMixin, self).add(*args, **kwargs)
         self.synchronize()
-        return super(DistributedMixin, self).add(*args, **kwargs)
